@@ -1022,8 +1022,6 @@ domod(Char *cp, Char type)
 
     case 'q':
     case 'x':
-	if (*cp == '\0')
-	    return Strsave(STRQNULL);
 	wp = Strsave(cp);
 	for (xp = wp; (c = *xp) != 0; xp++)
 	    if ((c != ' ' && c != '\t') || type == 'q')
